import asyncio

from mini.blockapi import errors
from mini.blockapi.base_api import BlockApiResultType
from mini.blockapi.block_expression import ControlBehavior, ControlBehaviorResponse, RobotBehaviorControlType
from mini.blockapi.block_expression import ControlMouthLamp, ControlMouthResponse
from mini.blockapi.block_expression import PlayExpression, PlayExpressionResponse, RobotExpressionType
from mini.blockapi.block_expression import SetMouthLamp, SetMouthLampResponse, MouthLampColor
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown, test_start_run_program
from test.test_connect import test_get_device_by_name


# 测试让眼睛演示个表情
async def test_play_expression():
    # express_type: INNER 是指机器人内置的不可修改的表情动画, CUSTOM 是放置在sdcard/customize/expresss目录下可被开发者修改的表情
    block: PlayExpression = PlayExpression(express_name="codemao1", express_type=RobotExpressionType.INNER)
    # response: PlayExpressionResponse
    (resultType, response) = await block.execute()

    print(f'test_play_expression result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_play_expression timetout'
    assert response is not None and isinstance(response,
                                               PlayExpressionResponse), 'test_play_expression result unavailable'
    assert response.isSuccess, 'play_expression failed'


# 测试, 让机器人跳舞/停止跳舞
async def test_control_behavior():
    # control_type: START, STOP
    block: ControlBehavior = ControlBehavior(name="dance_0004", control_type=RobotBehaviorControlType.START)
    # response ControlBehaviorResponse
    (resultType, response) = await block.execute()

    print(f'test_control_behavior result: {response}')
    print(
        'resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_express_error_str(response.resultCode)))

    assert resultType == BlockApiResultType.Success, 'test_control_behavior timetout'
    assert response is not None and isinstance(response,
                                               ControlBehaviorResponse), 'test_control_behavior result unavailable'
    assert response.isSuccess, 'control_behavior failed'


# 测试, 设置嘴巴灯颜色
async def test_set_mouth_lamp():
    # color: 支持RED,GREEN,BLUE三种颜色
    # mode: 0,1
    # duration:-1
    # breath_duration:
    block: SetMouthLamp = SetMouthLamp(color=MouthLampColor.GREEN, model=0, duration=-1, breath_duration=1000)
    # response:SetMouthLampResponse
    (resultType, response) = await block.execute()

    print(f'test_set_mouth_lamp result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_set_mouth_lamp timetout'
    assert response is not None and isinstance(response, SetMouthLampResponse), 'test_set_mouth_lamp result unavailable'
    assert response.isSuccess or response.resultCode == 504, 'set_mouth_lamp failed'


# 测试,开关嘴巴灯
async def test_control_mouth_lamp():
    # is_open: True,False
    # response :ControlMouthResponse
    (resultType, response) = await ControlMouthLamp(is_open=True).execute()

    print(f'test_control_mouth_lamp result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_control_mouth_lamp timetout'
    assert response is not None and isinstance(response,
                                               ControlMouthResponse), 'test_control_mouth_lamp result unavailable'
    assert response.isSuccess or response.resultCode == 504, 'control_mouth_lamp failed'


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_play_expression())
        asyncio.get_event_loop().run_until_complete(test_set_mouth_lamp())
        asyncio.get_event_loop().run_until_complete(test_control_mouth_lamp())
        asyncio.get_event_loop().run_until_complete(test_control_behavior())
        asyncio.get_event_loop().run_until_complete(shutdown())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_faceinfo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_faceinfo.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x16\x63odemao_faceinfo.proto\"\x11\n\x0f\x46\x61\x63\x65InfoRequest\"h\n\x10\x46\x61\x63\x65InfoResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06gender\x18\x03 \x01(\x05\x12\x0b\n\x03\x61ge\x18\x04 \x01(\x05\x12\r\n\x05width\x18\x05 \x01(\x05\x12\x0e\n\x06height\x18\x06 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_FACEINFOREQUEST = _descriptor.Descriptor(
    name='FaceInfoRequest',
    full_name='FaceInfoRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=26,
    serialized_end=43,
)

_FACEINFORESPONSE = _descriptor.Descriptor(
    name='FaceInfoResponse',
    full_name='FaceInfoResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='FaceInfoResponse.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='name', full_name='FaceInfoResponse.name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='gender', full_name='FaceInfoResponse.gender', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='age', full_name='FaceInfoResponse.age', index=3,
            number=4, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='width', full_name='FaceInfoResponse.width', index=4,
            number=5, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='height', full_name='FaceInfoResponse.height', index=5,
            number=6, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=45,
    serialized_end=149,
)

DESCRIPTOR.message_types_by_name['FaceInfoRequest'] = _FACEINFOREQUEST
DESCRIPTOR.message_types_by_name['FaceInfoResponse'] = _FACEINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceInfoRequest = _reflection.GeneratedProtocolMessageType('FaceInfoRequest', (_message.Message,), {
    'DESCRIPTOR': _FACEINFOREQUEST,
    '__module__': 'codemao_faceinfo_pb2'
    # @@protoc_insertion_point(class_scope:FaceInfoRequest)
})
_sym_db.RegisterMessage(FaceInfoRequest)

FaceInfoResponse = _reflection.GeneratedProtocolMessageType('FaceInfoResponse', (_message.Message,), {
    'DESCRIPTOR': _FACEINFORESPONSE,
    '__module__': 'codemao_faceinfo_pb2'
    # @@protoc_insertion_point(class_scope:FaceInfoResponse)
})
_sym_db.RegisterMessage(FaceInfoResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



name = "mini"
from .blockapi import *
from .channels import *
from .pb2 import *
from .dns import *
from .mini_sdk import *
__all__ = [
    'blockapi',
    'channels',
    'pb2',
    'dns',
    'mini_sdk'
]


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_setmouthlamp.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_setmouthlamp.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1a\x63odemao_setmouthlamp.proto\"]\n\x13SetMouthLampRequest\x12\r\n\x05model\x18\x01 \x01(\x05\x12\r\n\x05\x63olor\x18\x02 \x01(\x05\x12\x10\n\x08\x64uration\x18\x03 \x01(\x05\x12\x16\n\x0e\x62reathDuration\x18\x04 \x01(\x05\"=\n\x14SetMouthLampResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_SETMOUTHLAMPREQUEST = _descriptor.Descriptor(
    name='SetMouthLampRequest',
    full_name='SetMouthLampRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='model', full_name='SetMouthLampRequest.model', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='color', full_name='SetMouthLampRequest.color', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='duration', full_name='SetMouthLampRequest.duration', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='breathDuration', full_name='SetMouthLampRequest.breathDuration', index=3,
            number=4, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=30,
    serialized_end=123,
)

_SETMOUTHLAMPRESPONSE = _descriptor.Descriptor(
    name='SetMouthLampResponse',
    full_name='SetMouthLampResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='SetMouthLampResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='SetMouthLampResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=125,
    serialized_end=186,
)

DESCRIPTOR.message_types_by_name['SetMouthLampRequest'] = _SETMOUTHLAMPREQUEST
DESCRIPTOR.message_types_by_name['SetMouthLampResponse'] = _SETMOUTHLAMPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetMouthLampRequest = _reflection.GeneratedProtocolMessageType('SetMouthLampRequest', (_message.Message,), {
    'DESCRIPTOR': _SETMOUTHLAMPREQUEST,
    '__module__': 'codemao_setmouthlamp_pb2'
    # @@protoc_insertion_point(class_scope:SetMouthLampRequest)
})
_sym_db.RegisterMessage(SetMouthLampRequest)

SetMouthLampResponse = _reflection.GeneratedProtocolMessageType('SetMouthLampResponse', (_message.Message,), {
    'DESCRIPTOR': _SETMOUTHLAMPRESPONSE,
    '__module__': 'codemao_setmouthlamp_pb2'
    # @@protoc_insertion_point(class_scope:SetMouthLampResponse)
})
_sym_db.RegisterMessage(SetMouthLampResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_controlmouthlamp.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_controlmouthlamp.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1e\x63odemao_controlmouthlamp.proto\"%\n\x13\x43ontrolMouthRequest\x12\x0e\n\x06isOpen\x18\x01 \x01(\x08\"=\n\x14\x43ontrolMouthResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_CONTROLMOUTHREQUEST = _descriptor.Descriptor(
    name='ControlMouthRequest',
    full_name='ControlMouthRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isOpen', full_name='ControlMouthRequest.isOpen', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=34,
    serialized_end=71,
)

_CONTROLMOUTHRESPONSE = _descriptor.Descriptor(
    name='ControlMouthResponse',
    full_name='ControlMouthResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='ControlMouthResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='ControlMouthResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=73,
    serialized_end=134,
)

DESCRIPTOR.message_types_by_name['ControlMouthRequest'] = _CONTROLMOUTHREQUEST
DESCRIPTOR.message_types_by_name['ControlMouthResponse'] = _CONTROLMOUTHRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ControlMouthRequest = _reflection.GeneratedProtocolMessageType('ControlMouthRequest', (_message.Message,), {
    'DESCRIPTOR': _CONTROLMOUTHREQUEST,
    '__module__': 'codemao_controlmouthlamp_pb2'
    # @@protoc_insertion_point(class_scope:ControlMouthRequest)
})
_sym_db.RegisterMessage(ControlMouthRequest)

ControlMouthResponse = _reflection.GeneratedProtocolMessageType('ControlMouthResponse', (_message.Message,), {
    'DESCRIPTOR': _CONTROLMOUTHRESPONSE,
    '__module__': 'codemao_controlmouthlamp_pb2'
    # @@protoc_insertion_point(class_scope:ControlMouthResponse)
})
_sym_db.RegisterMessage(ControlMouthResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio
import logging
from asyncio.futures import Future
from typing import Any, Union, Set, Optional

from google.protobuf import message as _message

from .channels.websocket_client import AbstractMsgHandler
from .channels.websocket_client import ubt_websocket as _websocket
from .dns.dns_browser import WiFiDeviceListener, WiFiDevice
from .dns.dns_browser import browser as _browser

log = logging.getLogger(__name__)
log.addHandler(logging.StreamHandler())
if log.level == logging.NOTSET:
    log.setLevel(logging.INFO)

browser = _browser()
websocket = _websocket()

"""
批量获取机器人设备监听类
"""


def set_log_level(level: int, save_file: str = None):
    log.setLevel(level)

    from .dns.dns_browser import log as log1
    log1.setLevel(log.level)

    from .channels.websocket_client import log as log2
    log2.setLevel(log.level)

    if save_file is not None:
        file_handler = logging.FileHandler(save_file)
        log.addHandler(file_handler)
        log1.addHandler(file_handler)
        log2.addHandler(file_handler)


class GetWiFiDeviceListListener(WiFiDeviceListener):
    devices: Union[Set[Any], Any]

    def __init__(self, devices):
        self.devices = devices or set()

    def on_device_updated(self, device: WiFiDevice) -> None:
        pass

    def on_device_removed(self, device: WiFiDevice) -> None:
        self.devices.remove(device)

    def on_device_found(self, device: WiFiDevice) -> None:
        self.devices.add(device)


"""
获取用户选择的机器人序号
"""


async def get_user_input(devices: tuple) -> int:
    try:
        i: int = 0
        for device in devices:
            print('{0}.{1}'.format(i, device))
            i += 1
        num_text = input(f'请输入选择连接的机器人序号:')
    except Exception as e:
        raise e
    else:
        return int(num_text)


"""
开启一个扫描机器人设备的任务
"""


def start_scan(loop: asyncio.AbstractEventLoop, name: str) -> Future:
    fut = loop.create_future()

    class _InnerLister(WiFiDeviceListener):

        @staticmethod
        def set_result(future: Future, device: WiFiDevice):
            if future.cancelled() or future.done():
                return
            log.info(f"found device : {device}")
            future.set_result(device)

        def on_device_found(self, device: WiFiDevice) -> None:
            if device.name.endswith(name):
                if fut.cancelled() or fut.done():
                    return
                loop.run_in_executor(None, browser.stop_scan)
                loop.call_soon(_InnerLister.set_result, fut, device)

        def on_device_updated(self, device: WiFiDevice) -> None:
            if device.name.endswith(name):
                if fut.cancelled() or fut.done():
                    return
                loop.run_in_executor(None, browser.stop_scan)
                loop.call_soon(_InnerLister.set_result, fut, device)

        def on_device_removed(self, device: WiFiDevice) -> None:
            if device.name.endswith(name):
                if fut.cancelled() or fut.done():
                    return
                loop.call_soon(_InnerLister.set_result, fut, device)

    log.info("start scanning...")
    browser.add_listener(_InnerLister())
    browser.start_scan(0)

    return fut


"""
获取当前局域网内，指定名字的机器人设备信息
"""


async def get_device_by_name(name: str, timeout: int) -> Optional[WiFiDevice]:
    async def start_scan_async():
        return await start_scan(asyncio.get_running_loop(), name)

    try:
        device: WiFiDevice = await asyncio.wait_for(start_scan_async(), timeout)
        return device
    except asyncio.TimeoutError:
        log.warning(f'scan device timeout')
        return None
    finally:
        browser.stop_scan()
        log.info("stop scan finished.")


"""
获取当前局域网内所有机器人设备信息
"""


async def get_device_list(timeout: int):
    devices: Set[WiFiDevice] = set()
    browser.add_listener(GetWiFiDeviceListListener(devices))
    browser.start_scan(0)
    await asyncio.sleep(timeout)
    browser.remove_all_listener()
    browser.stop_scan()
    return tuple(devices)


"""
链接机器人设备
"""


async def connect(device: WiFiDevice) -> bool:
    return await websocket.connect(device.address)


"""
注册命令监听器
"""


def register_msg_handler(cmd: int, handler: AbstractMsgHandler):
    websocket.register_msg_handler(cmd, handler)


"""
反注册命令监听器
"""


def unregister_msg_handler(cmd: int, handler: AbstractMsgHandler):
    websocket.unregister_msg_handler(cmd, handler)


"""
发送一个消息给机器人
"""


async def send_msg(cmd: int, message: _message.Message, timeout: int) -> Any:
    return await websocket.send_msg(cmd, message, timeout)


"""
断开链接，释放资源
"""


async def release():
    await websocket.shutdown()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_expressioninfo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_expressioninfo.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1c\x63odemao_expressioninfo.proto\"\x17\n\x15\x45xpressionInfoRequest\"@\n\x16\x45xpressionInfoResponse\x12\x11\n\texpressId\x18\x01 \x01(\x05\x12\x13\n\x0b\x65xpressName\x18\x02 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_EXPRESSIONINFOREQUEST = _descriptor.Descriptor(
    name='ExpressionInfoRequest',
    full_name='ExpressionInfoRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=32,
    serialized_end=55,
)

_EXPRESSIONINFORESPONSE = _descriptor.Descriptor(
    name='ExpressionInfoResponse',
    full_name='ExpressionInfoResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='expressId', full_name='ExpressionInfoResponse.expressId', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='expressName', full_name='ExpressionInfoResponse.expressName', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=57,
    serialized_end=121,
)

DESCRIPTOR.message_types_by_name['ExpressionInfoRequest'] = _EXPRESSIONINFOREQUEST
DESCRIPTOR.message_types_by_name['ExpressionInfoResponse'] = _EXPRESSIONINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExpressionInfoRequest = _reflection.GeneratedProtocolMessageType('ExpressionInfoRequest', (_message.Message,), {
    'DESCRIPTOR': _EXPRESSIONINFOREQUEST,
    '__module__': 'codemao_expressioninfo_pb2'
    # @@protoc_insertion_point(class_scope:ExpressionInfoRequest)
})
_sym_db.RegisterMessage(ExpressionInfoRequest)

ExpressionInfoResponse = _reflection.GeneratedProtocolMessageType('ExpressionInfoResponse', (_message.Message,), {
    'DESCRIPTOR': _EXPRESSIONINFORESPONSE,
    '__module__': 'codemao_expressioninfo_pb2'
    # @@protoc_insertion_point(class_scope:ExpressionInfoResponse)
})
_sym_db.RegisterMessage(ExpressionInfoResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio

from mini.blockapi.base_api import BlockApiResultType
from mini.blockapi.block_action import ChangeRobotVolume, ChangeRobotVolumeResponse
from mini.blockapi.block_action import GetActionList, GetActionListResponse, RobotActionType
from mini.blockapi.block_action import MoveRobot, MoveRobotDirection, MoveRobotResponse
from mini.blockapi.block_action import PlayAction, PlayActionResponse
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program


# 测试, 执行一个动作文件
async def test_play_action():
    # action_name: 动作文件名, 可以通过GetActionList获取机器人支持的动作
    block: PlayAction = PlayAction(action_name='018')
    # response: PlayActionResponse
    (resultType, response) = await block.execute()

    print(f'test_play_action result:{response}')

    assert resultType == BlockApiResultType.Success, 'test_play_action timetout'
    assert response is not None and isinstance(response, PlayActionResponse), 'test_play_action result unavailable'
    assert response.isSuccess, 'play_action failed'


# 测试, 控制机器人,向前/后/左/右 移动
async def test_move_robot():
    # step: 移动几步
    # direction: 方向,枚举类型
    block: MoveRobot = MoveRobot(step=10, direction=MoveRobotDirection.LEFTWARD)
    # response : MoveRobotResponse
    (resultType, response) = await block.execute()

    print(f'test_move_robot result:{response}')

    assert resultType == BlockApiResultType.Success, 'test_move_robot timetout'
    assert response is not None and isinstance(response, MoveRobotResponse), 'test_move_robot result unavailable'
    assert response.isSuccess, 'move_robot failed'


# 测试, 获取支持的动作文件列表
async def test_get_action_list():
    # action_type: INNER 是指机器人内置的不可修改的动作文件, CUSTOM 是放置在sdcard/customize/action目录下可被开发者修改的动作
    block: GetActionList = GetActionList(action_type=RobotActionType.INNER)
    # response:GetActionListResponse
    (resultType, response) = await block.execute()

    print(f'test_get_action_list result:{response}')

    assert resultType == BlockApiResultType.Success, 'test_get_action_list timetout'
    assert response is not None and isinstance(response,
                                               GetActionListResponse), 'test_get_action_list result unavailable'
    assert response.isSuccess, 'get_action_list failed'


# 测试, 改变机器人的音量
async def test_change_robot_volume():
    # volume: 0~1.0
    block: ChangeRobotVolume = ChangeRobotVolume(volume=0.5)
    # response:ChangeRobotVolumeResponse
    (resultType, response) = await block.execute()

    print(f'test_change_robot_volume result:{response}')

    assert resultType == BlockApiResultType.Success, 'test_change_robot_volume timetout'
    assert response is not None and isinstance(response,
                                               ChangeRobotVolumeResponse), 'test_change_robot_volume result unavailable'
    assert response.isSuccess, 'get_action_list failed'


async def main():
    device: WiFiDevice = await test_get_device_by_name()
    if device:
        await test_connect(device)
        await test_start_run_program()
        await test_play_action()
        await test_move_robot()
        await test_get_action_list()
        await test_change_robot_volume()
        await shutdown()


if __name__ == '__main__':
    asyncio.get_event_loop().run_until_complete(main())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_controlregisterface.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_controlregisterface.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n!codemao_controlregisterface.proto\"L\n\x1a\x43ontrolRegisterFaceRequest\x12\x0e\n\x06userId\x18\x01 \x01(\x05\x12\x10\n\x08userName\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"Z\n\x1b\x43ontrolRegisterFaceResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x12\x14\n\x0cregisterName\x18\x03 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_CONTROLREGISTERFACEREQUEST = _descriptor.Descriptor(
    name='ControlRegisterFaceRequest',
    full_name='ControlRegisterFaceRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='userId', full_name='ControlRegisterFaceRequest.userId', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='userName', full_name='ControlRegisterFaceRequest.userName', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='type', full_name='ControlRegisterFaceRequest.type', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=37,
    serialized_end=113,
)

_CONTROLREGISTERFACERESPONSE = _descriptor.Descriptor(
    name='ControlRegisterFaceResponse',
    full_name='ControlRegisterFaceResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='ControlRegisterFaceResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='ControlRegisterFaceResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='registerName', full_name='ControlRegisterFaceResponse.registerName', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=115,
    serialized_end=205,
)

DESCRIPTOR.message_types_by_name['ControlRegisterFaceRequest'] = _CONTROLREGISTERFACEREQUEST
DESCRIPTOR.message_types_by_name['ControlRegisterFaceResponse'] = _CONTROLREGISTERFACERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ControlRegisterFaceRequest = _reflection.GeneratedProtocolMessageType('ControlRegisterFaceRequest', (_message.Message,),
                                                                      {
                                                                          'DESCRIPTOR': _CONTROLREGISTERFACEREQUEST,
                                                                          '__module__': 'codemao_controlregisterface_pb2'
                                                                          # @@protoc_insertion_point(class_scope:ControlRegisterFaceRequest)
                                                                      })
_sym_db.RegisterMessage(ControlRegisterFaceRequest)

ControlRegisterFaceResponse = _reflection.GeneratedProtocolMessageType('ControlRegisterFaceResponse',
                                                                       (_message.Message,), {
                                                                           'DESCRIPTOR': _CONTROLREGISTERFACERESPONSE,
                                                                           '__module__': 'codemao_controlregisterface_pb2'
                                                                           # @@protoc_insertion_point(class_scope:ControlRegisterFaceResponse)
                                                                       })
_sym_db.RegisterMessage(ControlRegisterFaceResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio

from mini.blockapi.block_observe import ObserveInfraredDistance
from mini.blockapi.block_sound import PlayTTS
from mini.dns.dns_browser import WiFiDevice
from mini.pb2.codemao_observeinfrareddistance_pb2 import ObserveInfraredDistanceResponse
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program


async def test_ObserveInfraredDistance():
    # 红外监听对象
    observer: ObserveInfraredDistance = ObserveInfraredDistance()

    # 定义处理器
    # ObserveInfraredDistanceResponse.distance
    def handler(msg: ObserveInfraredDistanceResponse):
        print("distance = {0}".format(str(msg.distance)))
        if msg.distance < 500:
            observer.stop()
            asyncio.create_task(__tts())

    observer.set_handler(handler)
    observer.start()
    await asyncio.sleep(0)


async def __tts():
    result = await PlayTTS(text="是不是有人在啊， 你是谁啊").execute()
    print(f"tts over {result}")
    asyncio.get_running_loop().run_in_executor(None, asyncio.get_running_loop().stop)


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_ObserveInfraredDistance())
        asyncio.get_event_loop().run_forever()
        asyncio.get_event_loop().run_until_complete(shutdown())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_getregisterfaces.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import codemao_faceinfo_pb2 as codemao__faceinfo__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_getregisterfaces.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1e\x63odemao_getregisterfaces.proto\x1a\x16\x63odemao_faceinfo.proto\"\x19\n\x17GetRegisterFacesRequest\"g\n\x18GetRegisterFacesResponse\x12$\n\tfaceInfos\x18\x01 \x03(\x0b\x32\x11.FaceInfoResponse\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
    ,
    dependencies=[codemao__faceinfo__pb2.DESCRIPTOR, ])

_GETREGISTERFACESREQUEST = _descriptor.Descriptor(
    name='GetRegisterFacesRequest',
    full_name='GetRegisterFacesRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=58,
    serialized_end=83,
)

_GETREGISTERFACESRESPONSE = _descriptor.Descriptor(
    name='GetRegisterFacesResponse',
    full_name='GetRegisterFacesResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='faceInfos', full_name='GetRegisterFacesResponse.faceInfos', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='GetRegisterFacesResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='GetRegisterFacesResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=85,
    serialized_end=188,
)

_GETREGISTERFACESRESPONSE.fields_by_name['faceInfos'].message_type = codemao__faceinfo__pb2._FACEINFORESPONSE
DESCRIPTOR.message_types_by_name['GetRegisterFacesRequest'] = _GETREGISTERFACESREQUEST
DESCRIPTOR.message_types_by_name['GetRegisterFacesResponse'] = _GETREGISTERFACESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRegisterFacesRequest = _reflection.GeneratedProtocolMessageType('GetRegisterFacesRequest', (_message.Message,), {
    'DESCRIPTOR': _GETREGISTERFACESREQUEST,
    '__module__': 'codemao_getregisterfaces_pb2'
    # @@protoc_insertion_point(class_scope:GetRegisterFacesRequest)
})
_sym_db.RegisterMessage(GetRegisterFacesRequest)

GetRegisterFacesResponse = _reflection.GeneratedProtocolMessageType('GetRegisterFacesResponse', (_message.Message,), {
    'DESCRIPTOR': _GETREGISTERFACESRESPONSE,
    '__module__': 'codemao_getregisterfaces_pb2'
    # @@protoc_insertion_point(class_scope:GetRegisterFacesResponse)
})
_sym_db.RegisterMessage(GetRegisterFacesResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio
import logging

import mini.mini_sdk as MiniSdk
from mini.blockapi.block_setup import StartRunProgram
from mini.dns.dns_browser import WiFiDevice


# 搜索指定序列号(在机器人屁股后面)的机器人, 10秒超时
# 搜索的结果WiFiDevice, 包含机器人名称,ip,port等信息
async def test_get_device_by_name():
    result: WiFiDevice = await MiniSdk.get_device_by_name("00018", 10)
    print(f"test_get_device_by_name result:{result}")
    return result


# 搜索指定序列号(在机器人屁股后面)的机器人,
async def test_get_device_list():
    results = await MiniSdk.get_device_list(10)
    print(f"test_get_device_list results = {results}")
    return results


# MiniSdk.connect 返回值为bool, 这里忽略返回值
async def test_connect(dev: WiFiDevice):
    await MiniSdk.connect(dev)


# 进入编程模式,机器人有个tts播报,这里通过asyncio.sleep 让当前协程等6秒返回,让机器人播完
async def test_start_run_program():
    await StartRunProgram().execute()
    await asyncio.sleep(6)


# 断开连接并释放资源
async def shutdown():
    await asyncio.sleep(1)
    await MiniSdk.release()


# 默认的日志级别是Warning, 设置为INFO
MiniSdk.set_log_level(logging.INFO)

if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(shutdown())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: detectconfig.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='detectconfig.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\036com.ubt.alphamini.facedetector',
    serialized_pb=b'\n\x12\x64\x65tectconfig.proto\"6\n\x06\x43onfig\x12\x1b\n\x05level\x18\x01 \x01(\x0e\x32\x0c.DetectLevel\x12\x0f\n\x07timeout\x18\x02 \x01(\x05*:\n\x0b\x44\x65tectLevel\x12\x07\n\x03LOW\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\x08\n\x04HIGH\x10\x02\x12\x0c\n\x08ONE_SHOT\x10\x03\x42 \n\x1e\x63om.ubt.alphamini.facedetectorb\x06proto3'
)

_DETECTLEVEL = _descriptor.EnumDescriptor(
    name='DetectLevel',
    full_name='DetectLevel',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='LOW', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NORMAL', index=1, number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='HIGH', index=2, number=2,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ONE_SHOT', index=3, number=3,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=78,
    serialized_end=136,
)
_sym_db.RegisterEnumDescriptor(_DETECTLEVEL)

DetectLevel = enum_type_wrapper.EnumTypeWrapper(_DETECTLEVEL)
LOW = 0
NORMAL = 1
HIGH = 2
ONE_SHOT = 3

_CONFIG = _descriptor.Descriptor(
    name='Config',
    full_name='Config',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='level', full_name='Config.level', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='timeout', full_name='Config.timeout', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=22,
    serialized_end=76,
)

_CONFIG.fields_by_name['level'].enum_type = _DETECTLEVEL
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.enum_types_by_name['DetectLevel'] = _DETECTLEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR': _CONFIG,
    '__module__': 'detectconfig_pb2'
    # @@protoc_insertion_point(class_scope:Config)
})
_sym_db.RegisterMessage(Config)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio
import functools


def callback(future, n):
    print('{}: future done: {}'.format(n, future.result()))


async def register_callbacks(fut):
    print('registering callbacks on future')
    fut.add_done_callback(functools.partial(callback, n=1))
    fut.add_done_callback(functools.partial(callback, n=2))


async def main(fut):
    await register_callbacks(fut)
    print(f'{fut}')
    print('setting result of future')
    fut.set_result('the result')


event_loop = asyncio.get_event_loop()
try:
    all_done = asyncio.Future()
    event_loop.run_until_complete(main(all_done))
finally:
    event_loop.close()



#!/usr/bin/env python3

import asyncio

from mini.blockapi.block_observe import ObserveFaceDetect, FaceDetectTaskResponse
from mini.blockapi.block_observe import ObserveFaceRecognise, FaceRecogniseTaskResponse
from mini.blockapi.block_observe import ObserveHeadRacket, ObserveHeadRacketResponse
from mini.blockapi.block_observe import ObserveInfraredDistance, ObserveInfraredDistanceResponse
from mini.blockapi.block_observe import ObserveRobotPosture, ObserveFallClimbResponse
from mini.blockapi.block_observe import ObserveSpeechRecognise, SpeechRecogniseResponse
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program


async def test_speech_recognise():
    result = []

    observer: ObserveSpeechRecognise = ObserveSpeechRecognise()

    def handler(msg):
        print(f"test_speech_recognise handle msg:{msg.text}")

        assert msg is not None and isinstance(msg, SpeechRecogniseResponse), "test_speech_recognise result not " \
                                                                             "available "
        assert msg.isSuccess, "test_speech_recognise failed"

        assert len(msg.text), "test_speech_recognise text is nothing"

        result.append(msg.text)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveSpeechRecognise')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "test_speech_recognise result nil"


async def test_face_detect():
    result = []

    observer: ObserveFaceDetect = ObserveFaceDetect()

    def handler(msg):
        print(f"test_face_detect handle msg:{msg}")

        assert msg is not None and isinstance(msg, FaceDetectTaskResponse), "test_face_detect result not " \
                                                                            "available "
        assert msg.isSuccess, "test_face_detect failed"

        assert msg.count, "test_face_detect count is 0"

        result.append(msg.count)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveFaceDetect')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "test_face_detect result nil"


async def test_face_recognise():
    result = []

    observer: ObserveFaceRecognise = ObserveFaceRecognise()

    def handler(msg):
        print(f"test_face_recognise handle msg:{msg}")

        assert msg is not None and isinstance(msg, FaceRecogniseTaskResponse), "test_face_recognise result not " \
                                                                               "available "
        assert msg.isSuccess, "test_face_recognise failed"

        assert msg.faceInfos is not None, "test_face_recognise faceInfos is nil"

        result.append(msg.faceInfos)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveFaceRecognise')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "ObserveFaceRecognise result nil"


async def test_infrared_distance():
    result = []

    observer: ObserveInfraredDistance = ObserveInfraredDistance()

    def handler(msg):
        print(f"test_infrared_distance handle msg:{msg}")

        assert msg is not None and isinstance(msg, ObserveInfraredDistanceResponse), "test_infrared_distance result " \
                                                                                     "not " \
                                                                                     "available "
        # assert msg.isSuccess, "test_infrared_distance failed"

        assert msg.distance is not None and msg.distance > 0, "test_infrared_distance distance unavailable"

        result.append(msg.distance)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveInfraredDistance')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "ObserveInfraredDistance result nil"


async def test_robot_posture():
    result = []

    observer: ObserveRobotPosture = ObserveRobotPosture()

    def handler(msg):
        print(f"test_robot_posture handle msg:{msg}")

        assert msg is not None and isinstance(msg, ObserveFallClimbResponse), "test_robot_posture result " \
                                                                              "not " \
                                                                              "available "
        # assert msg.isSuccess, "test_infrared_distance failed"

        assert msg.status is not None and msg.status > 0, "test_robot_posture status unavailable"

        result.append(msg.status)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveRobotPosture')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "ObserveRobotPosture result nil"


async def test_head_racket():
    result = []

    observer: ObserveHeadRacket = ObserveHeadRacket()

    def handler(msg):
        print(f"test_head_racket handle msg:{msg}")

        assert msg is not None and isinstance(msg, ObserveHeadRacketResponse), "test_head_racket result " \
                                                                               "not " \
                                                                               "available "
        # assert msg.isSuccess, "test_infrared_distance failed"

        assert msg.type is not None and msg.type > 0, "test_head_racket type unavailable"

        result.append(msg.type)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveHeadRacket')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "ObserveHeadRacket result nil"


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())

        asyncio.get_event_loop().run_until_complete(test_speech_recognise())
        asyncio.get_event_loop().run_until_complete(test_face_detect())
        asyncio.get_event_loop().run_until_complete(test_face_recognise())
        asyncio.get_event_loop().run_until_complete(test_infrared_distance())
        asyncio.get_event_loop().run_until_complete(test_robot_posture())
        asyncio.get_event_loop().run_until_complete(test_head_racket())

        asyncio.get_event_loop().run_until_complete(shutdown())



#!/usr/bin/env python3

import enum


@enum.unique
class PCProgramCmdId(enum.Enum):
    """
    pcCodeMao的命令号配置
    """

    # IM_VERSION = 0x01
    # request
    RESPONSE_BASE = 1000

    """
    /**
     * 播放动作
     */
    """
    PLAY_ACTION_REQUEST = 1

    """
    /**
     * 移动机器人
     */
     """
    MOVE_ROBOT_REQUEST = 2

    """
    /**
     * 停止动作
     */
     """
    STOP_ACTION_REQUEST = 3

    """
    /**
     * 播放tts
     */
     """
    PLAY_TTS_REQUEST = 4

    """
    /**
     * 人脸识别
     */
     """
    FACE_DETECT_REQUEST = 5

    """
    /**
     * 识别人脸 （男性 女性）
     */
     """
    FACE_ANALYSIS_REQUEST = 6

    """
    /**
     * 物体 手势 花草识别
     */
     """
    RECOGNISE_OBJECT_REQUEST = 7

    """
    /**
     * 识别到某人
     */
     """
    FACE_RECOGNISE_REQUEST = 8

    """
    /**
     * 拍照
     */
     """
    TAKE_PICTURE_REQUEST = 9

    """
    /**
     * 播放表情
     */
     """
    PLAY_EXPRESSION_REQUEST = 10

    """
    /**
     *设置嘴巴灯
     */
     """
    SET_MOUTH_LAMP_REQUEST = 11

    """
    /**
     * 订阅红外检测障碍物距离：监听
     */
     """
    SUBSCRIBE_INFRARED_DISTANCE_REQUEST = 12

    """
    /**
     * 订阅机器人姿态：监听
     */
     """
    SUBSCRIBE_ROBOT_POSTURE_REQUEST = 13

    """
    /**
     * 订阅拍头事件：监听
     */
     """
    SUBSCRIBE_HEAD_RACKET_REQUEST = 14

    """
    /**
     * 控制行为
     */
     """
    CONTROL_BEHAVIOR_REQUEST = 15

    """
    /**
     * 获取版本号
     */
    """
    GET_ROBOT_VERSION_REQUEST = 16
    GET_ROBOT_VERSION_RESPONSE = RESPONSE_BASE + GET_ROBOT_VERSION_REQUEST

    """
    /**
     * 获取红外距离
     */
     """
    GET_INFRARED_DISTANCE_REQUEST = 19

    """
    /**
     * 停止所有操作
     */
     """
    REVERT_ORIGIN_REQUEST = 20

    """
    /**
     * 断开tcp
     */
     """
    DISCONNECTION_REQUEST = 21

    """
    /**
     * 开关嘴巴灯
     */
     """
    SWITCH_MOUTH_LAMP_REQUEST = 22

    """
    /**
     * 播放音效
     */
     """
    PLAY_AUDIO_REQUEST = 23

    """
    /**
     * 停止音效
     */
     """
    STOP_AUDIO_REQUEST = 24

    """
    /**
     * 获取音效列表
     */
     """
    GET_AUDIO_LIST_REQUEST = 25

    """
    /**
     * 翻译
     */
     """
    TRANSLATE_REQUEST = 26

    """
    /**
     * 百科
     */
     """
    WIKI_REQUEST = 27

    """
    /**
     * 改变机器人音量
     */
     """
    CHANGE_ROBOT_VOLUME_REQUEST = 28

    """
    /**
     * 播放在线音乐
     */
     """
    PLAY_ONLINE_MUSIC_REQUEST = 29

    """
    /**
     * 人脸侦测任务(持续侦测)：监听
     */
     """
    FACE_DETECT_TASK_REQUEST = 30
    """
    /**
     * 获取熟人列表
     */
     """
    GET_REGISTER_FACES_REQUEST = 31

    """
    /**
     * 人脸识别（持续识别）：监听
     */
     """
    FACE_RECOGNISE_TASK_REQUEST = 32

    """
    /**
     * 获取机器人动作列表
     */
     """
    GET_ACTION_LIST = 33

    """
    /**
     * 控制机器人录音/播放/暂停等
     */
     """
    CONTROL_ROBOT_AUDIO_RECORD = 34

    """
    /**
     * 语音识别：监听
     */
     """
    SPEECH_RECOGNISE = 35

    """
    /**
     * 获取服务器信息
     */
     """
    GET_SERVER_INFO = 36  # TODO

    """
    /**
     * 播放自定义动作
     */
     """
    PLAY_CUSTOM_ACTION_REQUEST = 37

    """
    /**
     * 停止自定义动作
     */
     """
    STOP_CUSTOM_ACTION_REQUEST = 38

    """
    /**
     * 停止语音识别
     */
    """
    STOP_SPEECH_RECOGNISE_REQUEST = 39



import asyncio

from mini.blockapi.base_api import BlockApiResultType
from mini.blockapi.block_sence import FaceAnalysis, FaceAnalyzeResponse
from mini.blockapi.block_sence import FaceDetect, FaceDetectResponse
from mini.blockapi.block_sence import FaceRecognise, FaceRecogniseResponse
from mini.blockapi.block_sence import GetInfraredDistance, GetInfraredDistanceResponse
from mini.blockapi.block_sence import GetRegisterFaces, GetRegisterFacesResponse
from mini.blockapi.block_sence import ObjectRecognise, RecogniseObjectResponse, ObjectRecogniseType
from mini.blockapi.block_sence import TakePicture, TakePictureResponse, TakePictureType
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown, test_start_run_program
from test.test_connect import test_get_device_by_name


# 测试人脸侦测
async def test_face_detect():
    # timeout: 指定侦测时长
    block: FaceDetect = FaceDetect(timeout=10)
    # response: FaceDetectResponse
    (resultType, response) = await block.execute()

    print(f'test_face_detect result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_face_detect timetout'
    assert response is not None and isinstance(response, FaceDetectResponse), 'test_face_detect result unavailable'
    assert response.isSuccess, 'face_detect failed'


# 测试人脸分析
async def test_face_analysis():
    block: FaceAnalysis = FaceAnalysis(timeout=10)
    # response: FaceAnalyzeResponse
    (resultType, response) = await block.execute()

    print(f'test_face_analysis result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_face_analysis timetout'
    assert response is not None and isinstance(response, FaceAnalyzeResponse), 'test_face_analysis result unavailable'
    assert response.isSuccess, 'face_analysis failed'


# 测试物体识别
async def test_object_Recognise():
    # object_type: 支持FLOWER, FRUIT, GESTURE 三类物体
    block: ObjectRecognise = ObjectRecognise(object_type=ObjectRecogniseType.FLOWER, timeout=10)
    # response : RecogniseObjectResponse
    (resultType, response) = await block.execute()

    print(f'test_object_Recognise result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_object_Recognise timetout'
    assert response is not None and isinstance(response,
                                               RecogniseObjectResponse), 'test_object_Recognise result unavailable'
    assert response.isSuccess, 'test_object_Recognise failed'


# 测试拍照
async def test_take_picture():
    # response: TakePictureResponse
    # take_picture_type: IMMEDIATELY-立即拍照, FINDFACE-找到人脸再拍照 两种拍照效果
    (resultType, response) = await TakePicture(take_picture_type=TakePictureType.IMMEDIATELY).execute()

    print(f'test_take_picture result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_take_picture timetout'
    assert response is not None and isinstance(response, TakePictureResponse), 'test_take_picture result unavailable'
    assert response.isSuccess, 'test_take_picture failed'


# 测试人脸识别
async def test_face_recognise():
    # response : FaceRecogniseResponse
    (resultType, response) = await FaceRecognise(timeout=10).execute()

    print(f'test_face_recognise result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_face_recognise timetout'
    assert response is not None and isinstance(response,
                                               FaceRecogniseResponse), 'test_face_recognise result unavailable'
    assert response.isSuccess, 'test_face_recognise failed'


# 测试获取红外探测距离
async def test_get_infrared_distance():
    # response: GetInfraredDistanceResponse
    (resultType, response) = await GetInfraredDistance().execute()

    print(f'test_get_infrared_distance result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_get_infrared_distance timetout'
    assert response is not None and isinstance(response,
                                               GetInfraredDistanceResponse), 'test_get_infrared_distance result unavailable'
    assert response.distance > 0, 'test_get_infrared_distance failed'


# 测试获取目前机器人内注册的人脸个数
async def test_get_register_faces():
    # reponse : GetRegisterFacesResponse
    (resultType, response) = await GetRegisterFaces().execute()

    print(f'test_get_register_faces result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_get_register_faces timetout'
    assert response is not None and isinstance(response,
                                               GetRegisterFacesResponse), 'test_get_register_faces result unavailable'
    assert response.isSuccess, 'test_get_register_faces failed'


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_face_detect())
        asyncio.get_event_loop().run_until_complete(test_face_analysis())
        asyncio.get_event_loop().run_until_complete(test_take_picture())
        asyncio.get_event_loop().run_until_complete(test_face_recognise())
        asyncio.get_event_loop().run_until_complete(test_get_infrared_distance())
        asyncio.get_event_loop().run_until_complete(test_get_register_faces())
        asyncio.get_event_loop().run_until_complete(shutdown())



import asyncio

from mini.blockapi.block_observe import ObserveRobotPosture
from mini.blockapi.block_sound import PlayTTS
from mini.dns.dns_browser import WiFiDevice
from mini.pb2.codemao_observefallclimb_pb2 import ObserveFallClimbResponse
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program


# 测试,姿态检测
async def test_ObserveRobotPosture():
    # 创建监听对象
    observer: ObserveRobotPosture = ObserveRobotPosture()

    # 事件处理器
    # ObserveFallClimbResponse.status
    #     STAND = 1; //站立
    #     SPLITS_LEFT = 2; //左劈叉
    #     SPLITS_RIGHT = 3; //右劈叉
    #     SITDOWN = 4; //坐下
    #     SQUATDOWN = 5; //蹲下
    #     KNEELING = 6; //跪下
    #     LYING = 7; //侧躺
    #     LYINGDOWN = 8; //平躺
    #     SPLITS_LEFT_1 = 9; //左劈叉1
    #     SPLITS_RIGHT_2 = 10;//右劈叉2
    #     BEND = 11;//弯腰
    def handler(msg: ObserveFallClimbResponse):
        print("{0}".format(msg))
        if msg.status == 8 or msg.status == 7:
            observer.stop()
            asyncio.create_task(__tts())

    observer.set_handler(handler)
    # start
    observer.start()
    await asyncio.sleep(0)


async def __tts():
    await PlayTTS(text="我摔倒了").execute()
    asyncio.get_running_loop().run_in_executor(None, asyncio.get_running_loop().stop)


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_ObserveRobotPosture())
        asyncio.get_event_loop().run_forever()
        asyncio.get_event_loop().run_until_complete(shutdown())



import base64
import logging
from functools import wraps

from google.protobuf import message as _message

from ..pb2.pccodemao_message_pb2 import Message
from ..pb2.pccodemao_messageheader_pb2 import MessageHeader

log = logging.getLogger(__name__)
log.addHandler(logging.NullHandler())
if log.level == logging.NOTSET:
    log.setLevel(logging.WARN)


def build_request_msg(cmd: int, send_serial: int, request: _message.Message) -> Message:
    msg = Message()
    msg.bodyData = request.SerializeToString()
    msg_header: MessageHeader = MessageHeader()
    msg_header.command = cmd
    msg_header.id = str(send_serial)
    # msg_header.responseSerial = 0
    msg.header.CopyFrom(msg_header)
    return msg


def build_response_msg(cmd: int, send_serial: int, response: _message.Message) -> Message:
    msg = Message()
    msg.bodyData = response.SerializeToString()
    msg_header = MessageHeader()
    msg_header.command = cmd
    msg_header.id = send_serial
    # msg_header.responseSerial = response_serial
    msg.header.CopyFrom(msg_header)
    return msg


def parse_msg(recv: str) -> Message:
    msg = Message()
    msg.ParseFromString(recv)
    return msg


def parse_body_msg(recv: bytes, clazz: type(_message.Message)) -> _message.Message:
    return clazz().ParseFromString(recv)
    # clazz.ParseFromString(recv)


def base64_encode(b: bytes) -> str:
    log.debug("{0} -----> {1}".format(str(b), str(base64.b64encode(b))))
    return "{0}&".format(str(base64.b64encode(b))[2:-1])


def base64_decode(b: str) -> str:
    log.debug("{0}".format(str(b)))
    return base64.b64decode(b[:-1])


def coroutine(func):
    @wraps(func)
    def primer(*args, **kwargs):
        gen = func(*args, **kwargs)
        next(gen)
        return gen

    return primer


@coroutine
def id_generator():
    identify = 0
    while True:
        yield identify
        identify += 1



import abc
import asyncio
import logging
import threading
from asyncio import Future
from typing import Type, Any

import websockets
import websockets.exceptions
from google.protobuf import message as _message
from websockets.exceptions import ConnectionClosed, ConnectionClosedOK

from ..channels import msg_utils as msg_utils
from ..pb2.pccodemao_message_pb2 import Message

log = logging.getLogger(__name__)
log.addHandler(logging.StreamHandler())
if log.level == logging.NOTSET:
    log.setLevel(logging.WARNING)


class AbstractMsgHandler(abc.ABC):

    def __init__(self, identify=0, msg_clazz: type(_message.Message) = Message):
        if issubclass(msg_clazz, _message.Message):
            self.__msg_clazz = msg_clazz or Message
            self.__identify = identify
        else:
            class_name = type(self).__name__
            raise Exception(f'{class_name} is not subclass of {Message.__name__}')

    @abc.abstractmethod
    def handle_msg(self, message: _message.Message):
        """
        :param message: Message
        :return:
        """

    def parse_msg(self, body_data):
        if self.msg_clazz == Message:
            log.info('no need parse body message.')
            return body_data
        return self.msg_clazz().ParseFromString(body_data)

    @property
    def msg_clazz(self):
        return self.__msg_clazz

    @property
    def identify(self):
        return self.__identify

    def __repr__(self):
        class_name = type(self).__name__
        msg_clazz_name = type(self.msg_clazz).__name__
        return '({!r}, {!r}, {!r})'.format(class_name, msg_clazz_name, self.__identify)


class DefaultMsgHandler(AbstractMsgHandler):

    def handle_msg(self, message: _message.Message):
        log.warning(f'handle msg: {message}')


class _CoroutineHandler(AbstractMsgHandler):

    def __init__(self, identify, future: Future):
        super().__init__(identify)
        self.coroutine = None
        self.__future = future

    def handle_msg(self, message: _message.Message):
        log.debug(f'receiver message = {message}')
        if self.__future.cancelled() or self.__future.done():
            return
        self.__future.set_result(message)


class _MessageDispatcher(object):

    def __init__(self):
        self.__handlers = {}

    def add_handler(self, cmd, msg_handler: AbstractMsgHandler = DefaultMsgHandler(Message)):
        if isinstance(msg_handler, AbstractMsgHandler):
            self.handlers.setdefault(cmd, []).append(msg_handler)
        else:
            class_name = type(msg_handler).__name__
            raise Exception(f'{class_name} is not instance of {AbstractMsgHandler.__name__}')

    def remove_handler(self, cmd):
        del self.handlers[cmd]

    def remove_handler0(self, cmd, handler: AbstractMsgHandler):
        self.handlers.get(cmd).remove(handler)

    def __len__(self):
        return len(self.handlers)

    def __iter__(self):
        return tuple(self.handlers)

    @property
    def handlers(self):
        return self.__handlers

    def __repr__(self):
        return '{}({!r})'.format(*self)

    def dispatch(self, message: Message):
        header = message.header
        handler_list = self.handlers.get(header.command)
        if handler_list is not None:
            found: bool = False
            for handler in handler_list:
                if header.id == str(handler.identify):
                    log.debug(f'find handler = {handler}')
                    found = True
                    handler.handle_msg(message)
                    if isinstance(handler, _CoroutineHandler):
                        log.debug(f'remove cmd={header.command} handlers.')
                        self.remove_handler(header.command)
            if not found:
                log.warning(f'1.ignore: cmd={header.command}, cmd no handlers')
        else:
            log.warning(f'2.ignore:cmd={header.command}, cmd no handlers.')


class _UBTWebSocketClient(object):
    __init_flag = False
    _instance_lock = threading.Lock()

    def __init__(self):
        if not _UBTWebSocketClient.__init_flag:
            _UBTWebSocketClient.__init_flag = True
            log.info(f'init {_UBTWebSocketClient.__name__}')
            self._client = None
            self.__ip = 'localhost'
            self.__port = 8800
            self.__dispatcher = _MessageDispatcher()
            self.__generator = msg_utils.id_generator()

    def __new__(cls, *args, **kwargs):
        if not hasattr(_UBTWebSocketClient, "_instance"):
            with _UBTWebSocketClient._instance_lock:
                if not hasattr(_UBTWebSocketClient, "_instance"):
                    _UBTWebSocketClient._instance = object.__new__(cls)
        return _UBTWebSocketClient._instance

    @property
    def ip(self):
        return self.__ip

    @property
    def port(self):
        return self.__port

    @property
    def alive(self):
        return self._client and (not self._client.closed)

    def __format__(self, format_spec=''):
        return 'ip={!r},port={!r}'.format(self.__ip, self.__port)

    def __repr__(self):
        class_name = type(self).__name__
        return '{!r}({!r}, {!r})'.format(class_name, self.__ip, self.__port)

    async def connect(self, ip_address='localhost', port=8800, timeout=15000) -> bool:
        self.__ip = ip_address
        self.__port = port
        return await asyncio.wait_for(self.__connect(), timeout)

    async def __connect(self) -> bool:
        if self.alive:
            await self._client.close(reason='exit for reconnecting.')
        try:
            log.info(f'connect begin')
            self._client = await websockets.connect('ws://{}:{!r}'.format(self.ip, self.port))
            log.info(f'connect success')
            # self.__loop()
            asyncio.create_task(self.__loop())
            # asyncio.get_running_loop().run_forever()
            return True
        except OSError as error:
            log.error(f'WebSocket server no startUp: error{error}')
            return False

    async def __loop(self):
        log.debug(f'begin loop.')
        while self.alive:
            _data = None
            try:
                _data = await self._client.recv()
                # do parse
                _bytes = msg_utils.base64_decode(_data)
                msg = msg_utils.parse_msg(_bytes)
                log.info(f"recv msg: {msg}")
                # do dispatch
                self.__dispatch(msg)
            except Exception as e:
                if isinstance(e, ConnectionClosedOK):
                    log.warning("connection closed ok!")
                else:
                    log.exception('recv fail : %r', e)
        log.debug(f'end loop.')
        # loop = asyncio.get_running_loop()
        # if loop is not None:
        #     loop.close()

    def __dispatch(self, message: Message):
        self.__dispatcher.dispatch(message)

    async def send_msg0(self, cmd, message: _message.Message) -> bool:
        if self.alive:
            client = self._client
            identify = 0
            pccode_mao_message: Message = msg_utils.build_request_msg(cmd, send_serial=identify, request=message)

            async def send0():
                try:
                    await client.send(msg_utils.base64_encode(pccode_mao_message.SerializeToString()))
                    log.info(
                        'send cmd={!r}, identify={!r}, message={!r}'.format(pccode_mao_message.header.command,
                                                                            pccode_mao_message.header.id,
                                                                            message))
                    return True
                except (ConnectionClosed, ConnectionClosedOK) as close:
                    log.warning(f'Waring: connect is closed: {close}')
                    return False
                except (ConnectionError, ConnectionResetError, ConnectionAbortedError, ConnectionRefusedError) as error:
                    log.warning(f'Waring: connect error: {error}')
                    return False

            try:
                await asyncio.create_task(send0())
                return True
            except Exception as e:
                log.warning(f'receiver response failure: {e}')
                return False
        else:
            log.warning(f"Waring: Client not connected!")
            return False

    def register_msg_handler(self, cmd, handler: AbstractMsgHandler):
        self.__dispatcher.add_handler(cmd, handler)

    def unregister_msg_handler(self, cmd, handler: AbstractMsgHandler = None):
        if handler is None:
            self.__dispatcher.remove_handler(cmd)
        else:
            self.__dispatcher.remove_handler0(cmd, handler)

    async def send_msg(self, cmd, message: _message.Message, timeout) -> Any:
        if self.alive:
            client = self._client
            identify = self.generate_id()
            pccode_mao_message: Message = msg_utils.build_request_msg(cmd, send_serial=identify, request=message)
            future = asyncio.get_running_loop().create_future()
            handler = _CoroutineHandler(identify, future)
            log.debug(f'register cmd={pccode_mao_message.header.command} handler={handler}')
            self.register_msg_handler(pccode_mao_message.header.command, handler)

            async def send1():
                try:
                    await client.send(msg_utils.base64_encode(pccode_mao_message.SerializeToString()))
                    log.info(
                        'send cmd={!r}, identify={!r}, message={!r}'.format(pccode_mao_message.header.command,
                                                                            pccode_mao_message.header.id,
                                                                            message))
                    return await future
                except (
                        ConnectionClosed, ConnectionClosedOK, ConnectionError, ConnectionResetError,
                        ConnectionAbortedError,
                        ConnectionRefusedError) as close:
                    log.warning(f'connect close. {close}')
                except Exception as e2:
                    log.warning(f'send message failure: {e2}')

            try:
                return await asyncio.wait_for(send1(), timeout)
            except Exception as e:
                log.warning(f'recv response  failure: {e}')
                return None
        else:
            log.warning(f'client is not alive')
            return None

    def generate_id(self) -> int:
        return self.__generator.send(0)

    async def shutdown(self):
        if self.alive:
            self.__generator.close()
            await self._client.close(reason="client closed")
        else:
            log.warning(f'client is not alive.')


ubt_websocket: Type[_UBTWebSocketClient] = _UBTWebSocketClient



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_playexpression.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_playexpression.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1c\x63odemao_playexpression.proto\"=\n\x15PlayExpressionRequest\x12\x13\n\x0b\x65xpressName\x18\x01 \x01(\t\x12\x0f\n\x07\x64irType\x18\x02 \x01(\x05\"?\n\x16PlayExpressionResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_PLAYEXPRESSIONREQUEST = _descriptor.Descriptor(
    name='PlayExpressionRequest',
    full_name='PlayExpressionRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='expressName', full_name='PlayExpressionRequest.expressName', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='dirType', full_name='PlayExpressionRequest.dirType', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=32,
    serialized_end=93,
)

_PLAYEXPRESSIONRESPONSE = _descriptor.Descriptor(
    name='PlayExpressionResponse',
    full_name='PlayExpressionResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='PlayExpressionResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='PlayExpressionResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=95,
    serialized_end=158,
)

DESCRIPTOR.message_types_by_name['PlayExpressionRequest'] = _PLAYEXPRESSIONREQUEST
DESCRIPTOR.message_types_by_name['PlayExpressionResponse'] = _PLAYEXPRESSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PlayExpressionRequest = _reflection.GeneratedProtocolMessageType('PlayExpressionRequest', (_message.Message,), {
    'DESCRIPTOR': _PLAYEXPRESSIONREQUEST,
    '__module__': 'codemao_playexpression_pb2'
    # @@protoc_insertion_point(class_scope:PlayExpressionRequest)
})
_sym_db.RegisterMessage(PlayExpressionRequest)

PlayExpressionResponse = _reflection.GeneratedProtocolMessageType('PlayExpressionResponse', (_message.Message,), {
    'DESCRIPTOR': _PLAYEXPRESSIONRESPONSE,
    '__module__': 'codemao_playexpression_pb2'
    # @@protoc_insertion_point(class_scope:PlayExpressionResponse)
})
_sym_db.RegisterMessage(PlayExpressionResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3

import asyncio

from mini.dns.dns_browser import WiFiDeviceListener, WiFiDevice


class MyDeviceListener(WiFiDeviceListener):

    def on_device_updated(self, device: WiFiDevice) -> None:
        pass

    def on_device_removed(self, device: WiFiDevice) -> None:
        pass

    def on_device_found(self, device: WiFiDevice):
        print(self, "onDeviceFound:", device)


listener = MyDeviceListener()

listener2 = MyDeviceListener()

from mini.channels.websocket_client import ubt_websocket as SocketClient

print(f'{SocketClient()}')

from mini.dns.dns_browser import browser


async def test_browser():
    browser().add_listener(listener)
    browser().add_listener(listener2)
    browser().remove_listener(None)
    browser().remove_all_listener()
    browser().start_scan(10000)
    await asyncio.sleep(10)
    try:
        input("Press enter to exit...\n\n")
    finally:
        browser().stop_scan()
        exit()


asyncio.get_event_loop().run_until_complete(test_browser())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_getaudiolist.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_getaudiolist.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1a\x63odemao_getaudiolist.proto\")\n\x13GetAudioListRequest\x12\x12\n\nsearchType\x18\x01 \x01(\x05\"T\n\x14GetAudioListResponse\x12\x15\n\x05\x61udio\x18\x01 \x03(\x0b\x32\x06.Audio\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\"%\n\x05\x41udio\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06suffix\x18\x02 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_GETAUDIOLISTREQUEST = _descriptor.Descriptor(
    name='GetAudioListRequest',
    full_name='GetAudioListRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='searchType', full_name='GetAudioListRequest.searchType', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=30,
    serialized_end=71,
)

_GETAUDIOLISTRESPONSE = _descriptor.Descriptor(
    name='GetAudioListResponse',
    full_name='GetAudioListResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='audio', full_name='GetAudioListResponse.audio', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='GetAudioListResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='GetAudioListResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=73,
    serialized_end=157,
)

_AUDIO = _descriptor.Descriptor(
    name='Audio',
    full_name='Audio',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='Audio.name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='suffix', full_name='Audio.suffix', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=159,
    serialized_end=196,
)

_GETAUDIOLISTRESPONSE.fields_by_name['audio'].message_type = _AUDIO
DESCRIPTOR.message_types_by_name['GetAudioListRequest'] = _GETAUDIOLISTREQUEST
DESCRIPTOR.message_types_by_name['GetAudioListResponse'] = _GETAUDIOLISTRESPONSE
DESCRIPTOR.message_types_by_name['Audio'] = _AUDIO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAudioListRequest = _reflection.GeneratedProtocolMessageType('GetAudioListRequest', (_message.Message,), {
    'DESCRIPTOR': _GETAUDIOLISTREQUEST,
    '__module__': 'codemao_getaudiolist_pb2'
    # @@protoc_insertion_point(class_scope:GetAudioListRequest)
})
_sym_db.RegisterMessage(GetAudioListRequest)

GetAudioListResponse = _reflection.GeneratedProtocolMessageType('GetAudioListResponse', (_message.Message,), {
    'DESCRIPTOR': _GETAUDIOLISTRESPONSE,
    '__module__': 'codemao_getaudiolist_pb2'
    # @@protoc_insertion_point(class_scope:GetAudioListResponse)
})
_sym_db.RegisterMessage(GetAudioListResponse)

Audio = _reflection.GeneratedProtocolMessageType('Audio', (_message.Message,), {
    'DESCRIPTOR': _AUDIO,
    '__module__': 'codemao_getaudiolist_pb2'
    # @@protoc_insertion_point(class_scope:Audio)
})
_sym_db.RegisterMessage(Audio)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio

from mini.blockapi import errors
from mini.blockapi.base_api import BlockApiResultType
from mini.blockapi.block_sound import FetchAudioList, GetAudioListResponse, AudioType
from mini.blockapi.block_sound import PlayAudio, PlayAudioResponse
from mini.blockapi.block_sound import PlayOnlineMusic, MusicResponse
from mini.blockapi.block_sound import PlayTTS, ControlTTSResponse, TTSControlType
from mini.blockapi.block_sound import StopAllAudio, StopAudioResponse
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program


# 测试text合成声音
async def test_play_tts():
    # is_serial:串行执行
    # text:要合成的文本
    # control_type: TTSControlType.START: 播放tts; TTSControlType.STOP: 停止tts
    block: PlayTTS = PlayTTS(text="你好， 我是悟空， 啦啦啦", control_type=TTSControlType.START)
    # 返回元组, response是个ControlTTSResponse
    (resultType, response) = await block.execute()

    print(f'test_play_tts result: {response}')
    # PlayTTS block的response包含resultCode和isSuccess
    # 如果resultCode !=0 可以通过errors.get_speech_error_str(response.resultCode)) 查询错误描述信息
    print('resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_speech_error_str(response.resultCode)))

    assert resultType == BlockApiResultType.Success, 'test_play_tts timetout'
    assert response is not None and isinstance(response, ControlTTSResponse), 'test_play_tts result unavailable'
    assert response.isSuccess, 'test_play_tts failed'


# 测试播放在线音效
async def test_play_audio():
    # 播放在线音效, url表示要播放的音效列表
    block: PlayAudio = PlayAudio(
        url=["http://yun.lnpan.com/music/download/ring/000/075/5653bae83917a892589b372782175dd8.amr"])
    # response是个PlayAudioResponse
    (resultType, response) = await block.execute()

    print(f'test_play_audio result: {response}')
    print('resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_speech_error_str(response.resultCode)))

    assert resultType == BlockApiResultType.Success, 'test_play_audio timetout'
    assert response is not None and isinstance(response, PlayAudioResponse), 'test_play_audio result unavailable'
    assert response.isSuccess, 'test_play_audio failed'


# 测试获取机器人的音效资源
async def test_get_audio_list():
    # audio_type: AudioType.INNER 是指机器人内置的不可修改的音效, AudioType.CUSTOM 是放置在sdcard/customize/music目录下可别开发者修改的音效
    block: FetchAudioList = FetchAudioList(audio_type=AudioType.INNER)
    # response是个GetAudioListResponse
    (resultType, response) = await block.execute()

    print(f'test_get_audio_list result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_get_audio_list timetout'
    assert response is not None and isinstance(response, GetAudioListResponse), 'test_play_audio result unavailable'
    assert response.isSuccess, 'test_get_audio_list failed'


# 测试停止正在播放的声音
async def test_stop_audio():
    # 设置is_serial=False, 表示只需将指令发送给机器人,await不需要等机器人执行完结果再返回
    block: PlayTTS = PlayTTS(is_serial=False, text="你让我说，让我说，不要打断我，不要打断我，不要打断我")
    response = await block.execute()
    print(f'test_stop_audio.play_tts: {response}')
    await asyncio.sleep(2)

    # 停止所有声音
    block: StopAllAudio = StopAllAudio()
    (resultType, response) = await block.execute()

    print(f'test_stop_audio:{response}')

    assert resultType == BlockApiResultType.Success, 'test_stop_audio timetout'
    assert response is not None and isinstance(response, StopAudioResponse), 'test_stop_audio result unavailable'
    assert response.isSuccess, 'test_stop_audio failed'


# 测试播放一首音乐
async def test_play_online_music():
    # 播放qq音乐, 需要在手机端授权
    block: PlayOnlineMusic = PlayOnlineMusic(name='我的世界')
    (resultType, response) = await block.execute()

    print(f'test_play_online_music result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_play_online_music timetout'
    assert response is not None and isinstance(response, MusicResponse), 'test_play_online_music result unavailable'
    assert response.isSuccess, 'test_play_online_music failed'


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_play_tts())
        asyncio.get_event_loop().run_until_complete(test_get_audio_list())
        asyncio.get_event_loop().run_until_complete(test_stop_audio())
        asyncio.get_event_loop().run_until_complete(test_play_online_music())
        asyncio.get_event_loop().run_until_complete(test_play_audio())
        asyncio.get_event_loop().run_until_complete(shutdown())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_actioninfo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_actioninfo.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x18\x63odemao_actioninfo.proto\"M\n\x11\x41\x63tionInfoRequest\x12\x10\n\x08\x61\x63tionId\x18\x01 \x01(\t\x12\x12\n\nactionName\x18\x02 \x01(\t\x12\x12\n\nactionType\x18\x03 \x01(\x05\"N\n\x12\x41\x63tionInfoResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x63nName\x18\x02 \x01(\t\x12\x0e\n\x06\x65nName\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_ACTIONINFOREQUEST = _descriptor.Descriptor(
    name='ActionInfoRequest',
    full_name='ActionInfoRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='actionId', full_name='ActionInfoRequest.actionId', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='actionName', full_name='ActionInfoRequest.actionName', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='actionType', full_name='ActionInfoRequest.actionType', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=28,
    serialized_end=105,
)

_ACTIONINFORESPONSE = _descriptor.Descriptor(
    name='ActionInfoResponse',
    full_name='ActionInfoResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='ActionInfoResponse.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='cnName', full_name='ActionInfoResponse.cnName', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='enName', full_name='ActionInfoResponse.enName', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='type', full_name='ActionInfoResponse.type', index=3,
            number=4, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=107,
    serialized_end=185,
)

DESCRIPTOR.message_types_by_name['ActionInfoRequest'] = _ACTIONINFOREQUEST
DESCRIPTOR.message_types_by_name['ActionInfoResponse'] = _ACTIONINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActionInfoRequest = _reflection.GeneratedProtocolMessageType('ActionInfoRequest', (_message.Message,), {
    'DESCRIPTOR': _ACTIONINFOREQUEST,
    '__module__': 'codemao_actioninfo_pb2'
    # @@protoc_insertion_point(class_scope:ActionInfoRequest)
})
_sym_db.RegisterMessage(ActionInfoRequest)

ActionInfoResponse = _reflection.GeneratedProtocolMessageType('ActionInfoResponse', (_message.Message,), {
    'DESCRIPTOR': _ACTIONINFORESPONSE,
    '__module__': 'codemao_actioninfo_pb2'
    # @@protoc_insertion_point(class_scope:ActionInfoResponse)
})
_sym_db.RegisterMessage(ActionInfoResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_switchtranslatemodel.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_switchtranslatemodel.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\"codemao_switchtranslatemodel.proto\"-\n\x1bSwitchTranslateModelRequest\x12\x0e\n\x06isOpen\x18\x01 \x01(\x08\"E\n\x1cSwitchTranslateModelResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_SWITCHTRANSLATEMODELREQUEST = _descriptor.Descriptor(
    name='SwitchTranslateModelRequest',
    full_name='SwitchTranslateModelRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isOpen', full_name='SwitchTranslateModelRequest.isOpen', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=38,
    serialized_end=83,
)

_SWITCHTRANSLATEMODELRESPONSE = _descriptor.Descriptor(
    name='SwitchTranslateModelResponse',
    full_name='SwitchTranslateModelResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='SwitchTranslateModelResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='SwitchTranslateModelResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=85,
    serialized_end=154,
)

DESCRIPTOR.message_types_by_name['SwitchTranslateModelRequest'] = _SWITCHTRANSLATEMODELREQUEST
DESCRIPTOR.message_types_by_name['SwitchTranslateModelResponse'] = _SWITCHTRANSLATEMODELRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SwitchTranslateModelRequest = _reflection.GeneratedProtocolMessageType('SwitchTranslateModelRequest',
                                                                       (_message.Message,), {
                                                                           'DESCRIPTOR': _SWITCHTRANSLATEMODELREQUEST,
                                                                           '__module__': 'codemao_switchtranslatemodel_pb2'
                                                                           # @@protoc_insertion_point(class_scope:SwitchTranslateModelRequest)
                                                                       })
_sym_db.RegisterMessage(SwitchTranslateModelRequest)

SwitchTranslateModelResponse = _reflection.GeneratedProtocolMessageType('SwitchTranslateModelResponse',
                                                                        (_message.Message,), {
                                                                            'DESCRIPTOR': _SWITCHTRANSLATEMODELRESPONSE,
                                                                            '__module__': 'codemao_switchtranslatemodel_pb2'
                                                                            # @@protoc_insertion_point(class_scope:SwitchTranslateModelResponse)
                                                                        })
_sym_db.RegisterMessage(SwitchTranslateModelResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_observefallclimb.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_observefallclimb.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1e\x63odemao_observefallclimb.proto\".\n\x17ObserveFallClimbRequest\x12\x13\n\x0bisSubscribe\x18\x01 \x01(\x08\"*\n\x18ObserveFallClimbResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_OBSERVEFALLCLIMBREQUEST = _descriptor.Descriptor(
    name='ObserveFallClimbRequest',
    full_name='ObserveFallClimbRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSubscribe', full_name='ObserveFallClimbRequest.isSubscribe', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=34,
    serialized_end=80,
)

_OBSERVEFALLCLIMBRESPONSE = _descriptor.Descriptor(
    name='ObserveFallClimbResponse',
    full_name='ObserveFallClimbResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='ObserveFallClimbResponse.status', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=82,
    serialized_end=124,
)

DESCRIPTOR.message_types_by_name['ObserveFallClimbRequest'] = _OBSERVEFALLCLIMBREQUEST
DESCRIPTOR.message_types_by_name['ObserveFallClimbResponse'] = _OBSERVEFALLCLIMBRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObserveFallClimbRequest = _reflection.GeneratedProtocolMessageType('ObserveFallClimbRequest', (_message.Message,), {
    'DESCRIPTOR': _OBSERVEFALLCLIMBREQUEST,
    '__module__': 'codemao_observefallclimb_pb2'
    # @@protoc_insertion_point(class_scope:ObserveFallClimbRequest)
})
_sym_db.RegisterMessage(ObserveFallClimbRequest)

ObserveFallClimbResponse = _reflection.GeneratedProtocolMessageType('ObserveFallClimbResponse', (_message.Message,), {
    'DESCRIPTOR': _OBSERVEFALLCLIMBRESPONSE,
    '__module__': 'codemao_observefallclimb_pb2'
    # @@protoc_insertion_point(class_scope:ObserveFallClimbResponse)
})
_sym_db.RegisterMessage(ObserveFallClimbResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: programme_facedetecting.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='programme_facedetecting.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\035com.ubtechinc.alpha.programme',
    serialized_pb=b'\n\x1dprogramme_facedetecting.proto\"\'\n\x14\x46\x61\x63\x65\x44\x65tectingRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x05\"`\n\x15\x46\x61\x63\x65\x44\x65tectingResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x12\x11\n\tcommandId\x18\x04 \x01(\tB\x1f\n\x1d\x63om.ubtechinc.alpha.programmeb\x06proto3'
)

_FACEDETECTINGREQUEST = _descriptor.Descriptor(
    name='FaceDetectingRequest',
    full_name='FaceDetectingRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='timeout', full_name='FaceDetectingRequest.timeout', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=33,
    serialized_end=72,
)

_FACEDETECTINGRESPONSE = _descriptor.Descriptor(
    name='FaceDetectingResponse',
    full_name='FaceDetectingResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='count', full_name='FaceDetectingResponse.count', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='FaceDetectingResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='FaceDetectingResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='commandId', full_name='FaceDetectingResponse.commandId', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=74,
    serialized_end=170,
)

DESCRIPTOR.message_types_by_name['FaceDetectingRequest'] = _FACEDETECTINGREQUEST
DESCRIPTOR.message_types_by_name['FaceDetectingResponse'] = _FACEDETECTINGRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceDetectingRequest = _reflection.GeneratedProtocolMessageType('FaceDetectingRequest', (_message.Message,), {
    'DESCRIPTOR': _FACEDETECTINGREQUEST,
    '__module__': 'programme_facedetecting_pb2'
    # @@protoc_insertion_point(class_scope:FaceDetectingRequest)
})
_sym_db.RegisterMessage(FaceDetectingRequest)

FaceDetectingResponse = _reflection.GeneratedProtocolMessageType('FaceDetectingResponse', (_message.Message,), {
    'DESCRIPTOR': _FACEDETECTINGRESPONSE,
    '__module__': 'programme_facedetecting_pb2'
    # @@protoc_insertion_point(class_scope:FaceDetectingResponse)
})
_sym_db.RegisterMessage(FaceDetectingResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_playaudio.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import cloudstorageurls_pb2 as cloudstorageurls__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_playaudio.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x17\x63odemao_playaudio.proto\x1a\x16\x63loudstorageurls.proto\"@\n\x10PlayAudioRequest\x12\x1c\n\x05\x63loud\x18\x01 \x01(\x0b\x32\r.CloudStorage\x12\x0e\n\x06volume\x18\x02 \x01(\x02\":\n\x11PlayAudioResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
    ,
    dependencies=[cloudstorageurls__pb2.DESCRIPTOR, ])

_PLAYAUDIOREQUEST = _descriptor.Descriptor(
    name='PlayAudioRequest',
    full_name='PlayAudioRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='cloud', full_name='PlayAudioRequest.cloud', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='volume', full_name='PlayAudioRequest.volume', index=1,
            number=2, type=2, cpp_type=6, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=51,
    serialized_end=115,
)

_PLAYAUDIORESPONSE = _descriptor.Descriptor(
    name='PlayAudioResponse',
    full_name='PlayAudioResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='PlayAudioResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='PlayAudioResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=117,
    serialized_end=175,
)

_PLAYAUDIOREQUEST.fields_by_name['cloud'].message_type = cloudstorageurls__pb2._CLOUDSTORAGE
DESCRIPTOR.message_types_by_name['PlayAudioRequest'] = _PLAYAUDIOREQUEST
DESCRIPTOR.message_types_by_name['PlayAudioResponse'] = _PLAYAUDIORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PlayAudioRequest = _reflection.GeneratedProtocolMessageType('PlayAudioRequest', (_message.Message,), {
    'DESCRIPTOR': _PLAYAUDIOREQUEST,
    '__module__': 'codemao_playaudio_pb2'
    # @@protoc_insertion_point(class_scope:PlayAudioRequest)
})
_sym_db.RegisterMessage(PlayAudioRequest)

PlayAudioResponse = _reflection.GeneratedProtocolMessageType('PlayAudioResponse', (_message.Message,), {
    'DESCRIPTOR': _PLAYAUDIORESPONSE,
    '__module__': 'codemao_playaudio_pb2'
    # @@protoc_insertion_point(class_scope:PlayAudioResponse)
})
_sym_db.RegisterMessage(PlayAudioResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cloudwiki.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import cloudtranslate_pb2 as cloudtranslate__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='cloudwiki.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x0f\x63loudwiki.proto\x1a\x14\x63loudtranslate.proto\"R\n\x04WiKi\x12\r\n\x05query\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x0e\n\x06suffix\x18\x03 \x01(\t\x12\x1b\n\x08platform\x18\x04 \x01(\x0e\x32\t.PlatformB\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
    ,
    dependencies=[cloudtranslate__pb2.DESCRIPTOR, ])

_WIKI = _descriptor.Descriptor(
    name='WiKi',
    full_name='WiKi',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='query', full_name='WiKi.query', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='prefix', full_name='WiKi.prefix', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='suffix', full_name='WiKi.suffix', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='platform', full_name='WiKi.platform', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=41,
    serialized_end=123,
)

_WIKI.fields_by_name['platform'].enum_type = cloudtranslate__pb2._PLATFORM
DESCRIPTOR.message_types_by_name['WiKi'] = _WIKI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WiKi = _reflection.GeneratedProtocolMessageType('WiKi', (_message.Message,), {
    'DESCRIPTOR': _WIKI,
    '__module__': 'cloudwiki_pb2'
    # @@protoc_insertion_point(class_scope:WiKi)
})
_sym_db.RegisterMessage(WiKi)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import setuptools

with open("README.md", "r") as f:
    long_desc = f.read()

setuptools.setup(
    name="alphamini",
    version="0.0.9",
    author='logic.peng',
    autho_email='logic.peng@ubtrobot.com',
    description="python sdk for ubtenic alphamini robot",
    long_description=long_desc,
    long_description_content_type="text/markdown",
    # url="",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'websockets',
        'ifaddr',
        'protobuf'
    ],
)



import asyncio

from mini.blockapi.block_observe import ObserveFaceDetect
from mini.blockapi.block_sound import PlayTTS
from mini.dns.dns_browser import WiFiDevice
from mini.pb2.codemao_facedetecttask_pb2 import FaceDetectTaskResponse
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program


# 人脸检测,检测到人脸,则上报事件
async def test_ObserveFaceDetect():
    observer: ObserveFaceDetect = ObserveFaceDetect()

    # FaceDetectTaskResponse.count
    # FaceDetectTaskResponse.isSuccess
    # FaceDetectTaskResponse.resultCode
    def handler(msg: FaceDetectTaskResponse):
        print(f"{msg}")
        if msg.isSuccess and msg.count:
            observer.stop()
            asyncio.create_task(__tts(msg.count))

    observer.set_handler(handler)
    observer.start()
    await asyncio.sleep(0)


async def __tts(count):
    await PlayTTS(text=f'在我面前好像有{count}个人').execute()
    asyncio.get_running_loop().run_in_executor(None, asyncio.get_running_loop().stop)


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_ObserveFaceDetect())
        asyncio.get_event_loop().run_forever()
        asyncio.get_event_loop().run_until_complete(shutdown())



#!/usr/bin/env python3

from ..blockapi.base_api import BaseBlockApi, DEFAULT_TIMEOUT
from ..blockapi.cmdid import PCProgramCmdId
from ..pb2.codemao_revertorigin_pb2 import RevertOriginRequest, RevertOriginResponse
from ..pb2.pccodemao_disconnection_pb2 import DisconnectionRequest, DisconnectionResponse
from ..pb2.pccodemao_getappversion_pb2 import GetAppVersionRequest, GetAppVersionResponse
from ..pb2.pccodemao_message_pb2 import Message


class StartRunProgram(BaseBlockApi):
    """
    进入编程模式
    """

    def __init__(self, is_serial: bool = True, ):
        self.__isSerial = is_serial

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = GetAppVersionRequest()

        cmd_id = PCProgramCmdId.GET_ROBOT_VERSION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = GetAppVersionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StopRunProgram(BaseBlockApi):
    """
    退出编程模式
    """

    def __init__(self, is_serial: bool = True, ):
        self.__isSerial = is_serial

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = DisconnectionRequest()

        cmd_id = PCProgramCmdId.DISCONNECTION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = DisconnectionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class RevertOrigin(BaseBlockApi):
    """
    复位
    """

    def __init__(self, is_serial: bool = True):
        self.__isSerial = is_serial

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = RevertOriginRequest()

        cmd_id = PCProgramCmdId.REVERT_ORIGIN_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = RevertOriginResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



import asyncio

from mini.blockapi.block_observe import ObserveSpeechRecognise
from mini.blockapi.block_sound import PlayTTS
from mini.dns.dns_browser import WiFiDevice
from mini.pb2.codemao_speechrecognise_pb2 import SpeechRecogniseResponse
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program


async def __tts():
    block: PlayTTS = PlayTTS(text="你好， 我是悟空， 啦里啦，啦里啦")
    response = await block.execute()
    print(f'tes_play_tts: {response}')


# 测试监听语音识别
async def test_speech_recognise():
    # 语音监听对象
    observe: ObserveSpeechRecognise = ObserveSpeechRecognise()

    # 处理器
    # SpeechRecogniseResponse.text
    # SpeechRecogniseResponse.isSuccess
    # SpeechRecogniseResponse.resultCode
    def handler(msg: SpeechRecogniseResponse):
        print(f'=======handle speech recognise:{msg}')
        print("{0}".format(str(msg.text)))
        if str(msg.text) == "悟空":
            # 监听到"悟空", tts打个招呼
            asyncio.create_task(__tts())

        elif str(msg.text) == "结束":
            # 监听到结束, 停止监听
            observe.stop()
            # 结束event_loop
            asyncio.get_running_loop().run_in_executor(None, asyncio.get_running_loop().stop)

    observe.set_handler(handler)
    # 启动
    observe.start()
    await asyncio.sleep(0)


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_speech_recognise())
        asyncio.get_event_loop().run_forever()
        asyncio.get_event_loop().run_until_complete(shutdown())



#!/usr/bin/env python3

# 每种传感器做一个单例对象进行监听

import enum
import asyncio

from ..blockapi.base_api import BaseEventApi, BaseBlockApiNoNeedResponse
from ..blockapi.cmdid import PCProgramCmdId
from ..pb2.codemao_facedetecttask_pb2 import FaceDetectTaskRequest, FaceDetectTaskResponse
from ..pb2.codemao_facerecognisetask_pb2 import FaceRecogniseTaskRequest, FaceRecogniseTaskResponse
from ..pb2.codemao_observefallclimb_pb2 import ObserveFallClimbRequest, ObserveFallClimbResponse
from ..pb2.codemao_observeheadracket_pb2 import ObserveHeadRacketRequest, ObserveHeadRacketResponse
from ..pb2.codemao_observeinfrareddistance_pb2 import ObserveInfraredDistanceRequest, ObserveInfraredDistanceResponse
from ..pb2.codemao_speechrecognise_pb2 import SpeechRecogniseRequest, SpeechRecogniseResponse
from ..pb2.codemao_stopspeechrecognise_pb2 import StopSpeechRecogniseRequest, StopSpeechRecogniseResponse
from ..pb2.pccodemao_message_pb2 import Message


class ObserveSpeechRecognise(BaseEventApi):
    """
    监听语音识别
    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.SPEECH_RECOGNISE.value

        message = SpeechRecogniseRequest()

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=message)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = SpeechRecogniseResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):

        asyncio.create_task(StopSpeechRecognise().execute())

        super().stop()


class StopSpeechRecognise(BaseBlockApiNoNeedResponse):
    """
    停止语音识别
    """

    async def execute(self):

        request = StopSpeechRecogniseRequest()

        cmd_id = PCProgramCmdId.STOP_SPEECH_RECOGNISE_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = StopSpeechRecogniseResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ObserveFaceDetect(BaseEventApi):
    """
    监听人脸检测（个数）
    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.FACE_DETECT_TASK_REQUEST.value

        request = FaceDetectTaskRequest()

        # 单次侦测超时时间
        request.timeout = 1000

        # 侦测间隔时间
        request.period = 1000

        # 任务延时时间
        request.delay = 0

        # 检测开关
        request.switch = True

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=request)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceDetectTaskResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):

        asyncio.create_task(StopFaceDetect().execute())

        super().stop()


class StopFaceDetect(BaseBlockApiNoNeedResponse):
    """
    停止人脸检测（个数）
    """

    async def execute(self):

        request = FaceDetectTaskRequest()

        # 检测开关
        request.switch = False

        cmd_id = PCProgramCmdId.FACE_DETECT_TASK_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceDetectTaskResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ObserveFaceRecognise(BaseEventApi):
    """
    监听人脸识别
    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.FACE_RECOGNISE_TASK_REQUEST.value

        request = FaceRecogniseTaskRequest()

        # 单次侦测超时时间
        request.timeout = 1000

        # 侦测间隔时间
        request.period = 1000

        # 任务延时时间
        request.delay = 0

        # 检测开关
        request.switch = True

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=request)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceRecogniseTaskResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):

        asyncio.create_task(StopFaceRecognise().execute())

        super().stop()


class StopFaceRecognise(BaseBlockApiNoNeedResponse):
    """
    停止人脸识别
    """

    async def execute(self):

        request = FaceRecogniseTaskRequest()

        # 检测开关
        request.switch = False

        cmd_id = PCProgramCmdId.FACE_RECOGNISE_TASK_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceRecogniseTaskResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ObserveInfraredDistance(BaseEventApi):
    """
    监听红外距离
    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.SUBSCRIBE_INFRARED_DISTANCE_REQUEST.value

        request = ObserveInfraredDistanceRequest()

        # 检测周期
        request.samplingPeriod = 1000

        # 检测开关
        request.isSubscribe = True

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=request)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveInfraredDistanceResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):

        asyncio.create_task(StopObserveInfraredDistance().execute())

        super().stop()


class StopObserveInfraredDistance(BaseBlockApiNoNeedResponse):
    """
    停止监听红外距离
    """

    async def execute(self):

        request = ObserveInfraredDistanceRequest()

        # 检测开关
        request.isSubscribe = False

        cmd_id = PCProgramCmdId.FACE_RECOGNISE_TASK_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveInfraredDistanceResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class RobotPosture(enum.Enum):
    STAND = 1  # 站立
    SPLITS_LEFT = 2  # 左劈叉
    SPLITS_RIGHT = 3  # 右劈叉
    SIT_DOWN = 4  # 坐下
    SQUAT_DOWN = 5  # 蹲下
    KNEELING = 6  # 跪下
    LYING = 7  # 侧躺
    LYING_DOWN = 8  # 平躺
    SPLITS_LEFT_1 = 9  # 左劈叉1
    SPLITS_RIGHT_2 = 10  # 右劈叉2
    BEND = 11  # 弯腰


class ObserveRobotPosture(BaseEventApi):
    """
    监听机器人姿态
    姿态值对应：
    STAND = 1; //站立
    SPLITS_LEFT = 2; //左劈叉
    SPLITS_RIGHT = 3; //右劈叉
    SITDOWN = 4; //坐下
    SQUATDOWN = 5; //蹲下
    KNEELING = 6; //跪下
    LYING = 7; //侧躺
    LYINGDOWN = 8; //平躺
    SPLITS_LEFT_1 = 9; //左劈叉1
    SPLITS_RIGHT_2 = 10;//右劈叉2
    BEND = 11;//弯腰
    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.SUBSCRIBE_ROBOT_POSTURE_REQUEST.value

        request = ObserveFallClimbRequest()

        # 检测开关
        request.isSubscribe = True

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=request)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveFallClimbResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):

        asyncio.create_task(StopObserveRobotPosture().execute())

        super().stop()


class StopObserveRobotPosture(BaseBlockApiNoNeedResponse):
    """
    停止监听机器人姿态
    """

    async def execute(self):

        request = ObserveFallClimbRequest()

        # 检测开关
        request.isSubscribe = False

        cmd_id = PCProgramCmdId.SUBSCRIBE_ROBOT_POSTURE_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveFallClimbResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class HeadRacketType(enum.Enum):
    SINGLE_CLICK = 1  # 单击
    LONG_PRESS = 2  # 长按
    DOUBLE_CLICK = 3  # 双击


class ObserveHeadRacket(BaseEventApi):
    """
    监听拍头事件
    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.SUBSCRIBE_HEAD_RACKET_REQUEST.value

        message = ObserveHeadRacketRequest()

        # 检测开关
        message.isSubscribe = True

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=message)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveHeadRacketResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):

        asyncio.create_task(StopObserveHeadRacket().execute())

        super().stop()


class StopObserveHeadRacket(BaseBlockApiNoNeedResponse):
    """
    停止监听拍头事件
    """

    async def execute(self):

        request = ObserveHeadRacketRequest()

        # 检测开关
        request.isSubscribe = False

        cmd_id = PCProgramCmdId.SUBSCRIBE_ROBOT_POSTURE_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveHeadRacketResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



import asyncio

from mini.blockapi.block_expression import ControlBehavior
from mini.blockapi.block_observe import ObserveHeadRacket
from mini.dns.dns_browser import WiFiDevice
from mini.pb2.codemao_observeheadracket_pb2 import ObserveHeadRacketResponse
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program


# 测试, 触摸监听
async def test_ObserveHeadRacket():
    # 创建监听
    observer: ObserveHeadRacket = ObserveHeadRacket()

    # 事件处理器
    # ObserveHeadRacketResponse.type:
    # @enum.unique
    # class HeadRacketType(enum.Enum):
    #     SINGLE_CLICK = 1  # 单击
    #     LONG_PRESS = 2  # 长按
    #     DOUBLE_CLICK = 3  # 双击
    def handler(msg: ObserveHeadRacketResponse):
        # 监听到一个事件后,停止监听,
        observer.stop()
        print("{0}".format(str(msg.type)))
        # 执行个舞动
        asyncio.create_task(__dance())

    observer.set_handler(handler)
    # 启动
    observer.start()
    await asyncio.sleep(0)


async def __dance():
    await ControlBehavior(name="dance_0002").execute()
    # 结束event_loop
    asyncio.get_running_loop().run_in_executor(None, asyncio.get_running_loop().stop)


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_ObserveHeadRacket())
        # 定义了事件监听对象,必须让event_loop.run_forver()
        asyncio.get_event_loop().run_forever()
        asyncio.get_event_loop().run_until_complete(shutdown())
